@@ -1,6 +1,7 @@
 from typing import Union
 
 from jsf.schema_types._tuple import JSFTuple
+from jsf.schema_types.allof import AllOf
 from jsf.schema_types.anyof import AnyOf
 from jsf.schema_types.array import Array
 from jsf.schema_types.boolean import Boolean
@@ -31,6 +32,7 @@ AllTypes = Union[
     Number,
     Integer,
     AnyOf,
+    AllOf,
     OneOf,
 ]
 PrimativeTypes = Union[String, Boolean, Null, Number, Integer]
