@@ -10,7 +10,7 @@ class AnyOf(BaseSchema):
     def from_dict(d):
         return AnyOf(**d)
 
-    def generate(self, context: Dict[str, Any]) -> Optional[List[Any]]:
+    def generate(self, context: Dict[str, Any]) -> Optional[Any]:
         try:
             return super().generate(context)
         except ProviderNotSetException:
